def --env asp [
  profile?: string
  login?: string
] {
  if ($profile == null) {
    reset_aws_credentials
    print "AWS profile cleared."
    return
  }

  let available_profiles = (aws --no-cli-pager configure list-profiles | lines)
  if ($available_profiles | find $profile | is-empty) {
    print -e $"(ansi red)Profile ($profile) is not found."
    print -e $"Available profiles \(($available_profiles | str join ', ')\)(ansi reset)"
    return
  }

  reset_aws_credentials 
  $env.AWS_PROFILE = $profile
  $env.AWS_PROFILE_REGION = (aws configure get region)

  if ($login == "login") {
    aws sso login
    return
  }
}

def --env assume-role [
  role_arn: string
] {
  aws sts assume-role --role-arn $role_arn --role-session-name "AssumedConsoleUser" --output yaml
    | from yaml
    | get Credentials
    | load-env {
        AWS_ACCESS_KEY_ID: $in.AccessKeyId,
        AWS_SECRET_ACCESS_KEY: $in.SecretAccessKey,
        AWS_SESSION_TOKEN: $in.SessionToken,
      }
  hide-env --ignore-errors AWS_PROFILE
  hide-env --ignore-errors AWS_PROFILE_REGION
}

def reset_aws_credentials [] {
  [AWS_PROFILE, AWS_PROFILE_REGION, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_SESSION_TOKEN] | each { hide-env --ignore-errors $in }
}
